﻿################################################
#                                              #
#   HowNow Maintenance Powershell Script       #
#   Firebird v3                                #
#                                              #
#   Author: Tim Wilson                         #
#   Date:   02/11/17                           #
#                                              #
################################################

$ErrorActionPreference="SilentlyContinue"
Stop-Transcript | out-null
$ErrorActionPreference = "Continue"
$Date = Get-Date -for yyMMdd
Start-Transcript -path "$PSScriptRoot\Maintenance\${Date}MaintenanceOutput.log" -append
        
Write-Output "==================================="
Write-Output "=== HOWNOW DATABASE MAINTENANCE ==="
Write-Output "==================================="

$Gbak = "C:\Program Files\Firebird\Firebird_3_0\gbak.exe"

If(!(test-path ${Gbak}))
{
    Write-Output "Firebird installation not found. Exiting." 
    Return    
}

Write-Output "Maintenance script started."

Set-Alias -Name gbak -Value ${Gbak}

If(!(test-path "${PSScriptRoot}\Maintenance"))
{
    Write-Output "Creating maintenance subfolder..."
    New-Item -Path "${PSScriptRoot}" -Name "Maintenance" -ItemType "directory"
    Write-Output "Subfolder created."
}

Write-Output "Restarting firebird service..."

Restart-Service -name FirebirdServerDefaultInstance

If(test-path "${PSScriptRoot}\Maintenance\${Date}AutoBackup.FBK")
{
    Write-Output "Backup file for today already exisits. Script aborted."
    Return
}
						
Write-Output "Performing database backup..." 												
			
gbak -b -v "localhost:${PSScriptRoot}\HowNow.FDB" "${PSScriptRoot}\Maintenance\${Date}AutoBackup.FBK" -user sysdba -pass masterkey -y "${PSScriptRoot}\Maintenance\${Date}FirebirdBackup.log"

Write-Output "Database backup complete. Log created."

Write-Output "Stopping firebird service..."

Stop-Service -name FirebirdServerDefaultInstance

Write-Output "Creating redundancy snapshot of database..."

Copy-Item "${PSScriptRoot}\HowNow.FDB" "${PSScriptRoot}\Maintenance\${Date}AutoDBCopy.FDB"

Write-Output "Database copy saved to maintenance folder."

Write-Output "Starting firebird service..."

Start-Service -name FirebirdServerDefaultInstance

Write-Output "Performing database restore..."
 
gbak -rep -v "${PSScriptRoot}\Maintenance\${Date}AutoBackup.FBK" "${PSScriptRoot}\HowNow.FDB" -user SYSDBA -pass masterkey -y "${PSScriptRoot}\Maintenance\${Date}FirebirdRestore.log"

Write-Output "Database restore complete. Log created."

Write-Output "Restarting firebird service..."

Restart-Service -name FirebirdServerDefaultInstance

Write-Output "Checking for WebServer service..."

if (Get-Service HNWebServer -ErrorAction SilentlyContinue)
{
    Write-Output "Service found. Restarting..."
    Restart-Service -name HNWebServer
}

Write-Output "Checking for FileHelper service..."

if (Get-Service HowNowFileHelperService -ErrorAction SilentlyContinue)
{
    Write-Output "Service found. Restarting..."
    Restart-Service -name HowNowFileHelperService
}

Write-Output "Checking for HowNowServer service..."

if (Get-Service HowNow_Server -ErrorAction SilentlyContinue) 
{
    Write-Output "Service found. Restarting..."
    Restart-Service -name HowNowFileHelperService
}      

Write-Output "All installed services have been restarted."

Write-Output "Maintenance script complete."

Stop-Transcript